==> zio-aws-personalize_3-5.17.102.9-sources.jar: zio/aws/personalize/model/CreateCampaignResponse.scala <==
package zio.aws.personalize.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.personalize.model.primitives.Arn
import scala.jdk.CollectionConverters.*
final case class CreateCampaignResponse(campaignArn: Option[Arn] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.personalize.model.CreateCampaignResponse = {
    import CreateCampaignResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.personalize.model.CreateCampaignResponse
      .builder()
      .optionallyWith(
        campaignArn.map(value => Arn.unwrap(value): java.lang.String)
      )(_.campaignArn)
      .build()
  }
  def asReadOnly: zio.aws.personalize.model.CreateCampaignResponse.ReadOnly =
    zio.aws.personalize.model.CreateCampaignResponse.wrap(buildAwsValue())
}
object CreateCampaignResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.personalize.model.CreateCampaignResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.personalize.model.CreateCampaignResponse =
      zio.aws.personalize.model
        .CreateCampaignResponse(campaignArn.map(value => value))
    def campaignArn: Option[Arn]
    def getCampaignArn: ZIO[Any, AwsError, Arn] =
      AwsError.unwrapOptionField("campaignArn", campaignArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.personalize.model.CreateCampaignResponse
  ) extends zio.aws.personalize.model.CreateCampaignResponse.ReadOnly {
    override val campaignArn: Option[Arn] = scala
      .Option(impl.campaignArn())
      .map(value => zio.aws.personalize.model.primitives.Arn(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.personalize.model.CreateCampaignResponse
  ): zio.aws.personalize.model.CreateCampaignResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-personalize_3-5.17.295.17-sources.jar: zio/aws/personalize/model/CreateCampaignResponse.scala <==
package zio.aws.personalize.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.personalize.model.primitives.Arn
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class CreateCampaignResponse(
    campaignArn: Optional[Arn] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.personalize.model.CreateCampaignResponse = {
    import CreateCampaignResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.personalize.model.CreateCampaignResponse
      .builder()
      .optionallyWith(
        campaignArn.map(value => Arn.unwrap(value): java.lang.String)
      )(_.campaignArn)
      .build()
  }
  def asReadOnly: zio.aws.personalize.model.CreateCampaignResponse.ReadOnly =
    zio.aws.personalize.model.CreateCampaignResponse.wrap(buildAwsValue())
}
object CreateCampaignResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.personalize.model.CreateCampaignResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.personalize.model.CreateCampaignResponse =
      zio.aws.personalize.model
        .CreateCampaignResponse(campaignArn.map(value => value))
    def campaignArn: Optional[Arn]
    def getCampaignArn: ZIO[Any, AwsError, Arn] =
      AwsError.unwrapOptionField("campaignArn", campaignArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.personalize.model.CreateCampaignResponse
  ) extends zio.aws.personalize.model.CreateCampaignResponse.ReadOnly {
    override val campaignArn: Optional[Arn] = zio.aws.core.internal
      .optionalFromNullable(impl.campaignArn())
      .map(value => zio.aws.personalize.model.primitives.Arn(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.personalize.model.CreateCampaignResponse
  ): zio.aws.personalize.model.CreateCampaignResponse.ReadOnly = new Wrapper(
    impl
  )
}
